@@ -15,6 +15,28 @@ class GraphSetupError(TypeError):
         super().__init__(message)
 
 
+class GraphBuildingError(ValueError):
+    """An error raised during graph-building."""
+
+    message: str
+    """The error message."""
+
+    def __init__(self, message: str):
+        self.message = message
+        super().__init__(message)
+
+
+class GraphValidationError(ValueError):
+    """An error raised during graph validation."""
+
+    message: str
+    """The error message."""
+
+    def __init__(self, message: str):
+        self.message = message
+        super().__init__(message)
+
+
 class GraphRuntimeError(RuntimeError):
     """Error caused by an issue during graph execution."""
 
